/*! Built with http://stenciljs.com */
import { h } from './bscomponents.core.js';
import { p as _size, o as toLower, s as hasClass, r as removeClass, q as customEvent } from './chunk-d2b1926f.js';
import { a as closest } from './chunk-217bc533.js';
import { a as addClass } from './chunk-da49747d.js';
import { a as getTargetSelector } from './chunk-65570c01.js';
import './chunk-e18b632f.js';
import './chunk-ede00b3a.js';
// http://youmightnotneedjquery.com/
function toggleClass(el, className) {
    if (el.classList) {
        el.classList.toggle(className);
    }
    else {
        var classes = el.className.split(' ');
        var existingIndex = classes.indexOf(className);
        if (existingIndex >= 0) {
            classes.splice(existingIndex, 1);
        }
        else {
            classes.push(className);
        }
        // eslint-disable-next-line no-param-reassign
        el.className = classes.join(' ');
    }
}
function getDuplicatesInArray(rawArr) {
    var checkingArr = [];
    var dupArr = [];
    for (var j = 0, len = rawArr.length; j < len; j += 1) {
        if (checkingArr.indexOf(rawArr[j]) === -1) {
            checkingArr.push(rawArr[j]);
        }
        else if (dupArr.indexOf(rawArr[j]) === -1) {
            dupArr.push(rawArr[j]);
        }
    }
    return dupArr;
}
var BsButton = /** @class */ (function () {
    function BsButton() {
        this.tabindex = '0';
    }
    BsButton.prototype.componentWillLoad = function () {
        this.addFocusClass = false;
        if (this.tabindex === '-1') {
            this.tabindex = '';
        }
        if (this.tabindex === '0') {
            var input = this.bsButtonEl.querySelector('input');
            var buttonsToggler = closest(this.bsButtonEl, '[data-toggle="buttons"]');
            if (buttonsToggler && input) {
                this.addFocusClass = true;
                this.tabindex = '';
            }
        }
    };
    BsButton.prototype.handleFocusIn = function (event) {
        var isDisabled = hasClass(this.bsButtonEl, 'disabled');
        if (isDisabled) {
            return;
        }
        if (this.tabindex === '-1') {
            this.tabindex = '';
        }
        if (this.addFocusClass) {
            var closestButton = closest(event.target, '.btn');
            addClass(closestButton, 'focus');
        }
    };
    BsButton.prototype.handleFocusOut = function () {
        var isDisabled = hasClass(this.bsButtonEl, 'disabled');
        if (isDisabled) {
            return;
        }
        if (this.addFocusClass) {
            removeClass(this.bsButtonEl, 'focus');
        }
    };
    BsButton.prototype.handleKeyDown = function (event) {
        var isDisabled = hasClass(this.bsButtonEl, 'disabled');
        if (isDisabled) {
            return;
        }
        if (!this.bsButtonEl.contains(event.target)) {
            return;
        }
        if (event.which === 32) { // space
            if (!this.bsButtonEl.isEqualNode(event.target)) {
                // user pressed enter on some element element wrapped within bs-button
                if (toLower(event.target.tagName) === 'button'
                    && event.target.dataset.toggle !== 'collapse'
                    && event.target.dataset.toggle !== 'modal') {
                    // we let space go through if the button is not a collapse or modal trigger
                    return;
                }
                if (toLower(event.target.tagName) === 'a'
                    // && event.target.dataset.toggle !== 'collapse'
                    && event.target.dataset.toggle !== 'modal') {
                    // we let space go through if the button is not a modal trigger
                    return;
                }
            }
            if (event.stopPropagation) {
                event.stopPropagation();
                event.preventDefault();
            }
            console.log('space event: ', event);
            if (event.target.dataset.toggle === 'collapse') {
                BsButton.handleCollapseToggle(event.target);
                return;
            }
            if (event.target.dataset.toggle === 'modal') {
                BsButton.handleModalToggle(event.target);
                return;
            }
            this.handleToggle(this.bsButtonEl);
            return;
        }
        if (event.which === 13) { // enter
            if (!this.bsButtonEl.isEqualNode(event.target)) {
                // user pressed enter on some element element wrapped within bs-button
                if (toLower(event.target.tagName) === 'button'
                    && event.target.dataset.toggle !== 'collapse'
                    && event.target.dataset.toggle !== 'modal') {
                    // we let enter go through if the button is not a collapse or modal trigger
                    return; // leaving without preventing default
                }
                if (toLower(event.target.tagName) === 'a'
                    && event.target.dataset.toggle !== 'collapse'
                    && event.target.dataset.toggle !== 'modal') {
                    // we let enter go through if the anchor is not a collapse or modal trigger
                    return; // leaving without preventing default
                }
            }
            if (event.stopPropagation) {
                event.stopPropagation();
                event.preventDefault();
            }
            if (event.target.dataset.toggle === 'collapse') {
                BsButton.handleCollapseToggle(event.target);
                return;
            }
            if (event.target.dataset.toggle === 'modal') {
                BsButton.handleModalToggle(event.target);
                return;
            }
            this.handleToggle(this.bsButtonEl);
            return;
        }
        if (event.which === 27) { // esc
            if (event.stopPropagation) {
                event.stopPropagation();
                event.preventDefault();
            }
            document.activeElement.blur();
            if (this.addFocusClass) {
                removeClass(this.bsButtonEl, 'focus');
            }
        }
    };
    BsButton.prototype.handleButtonClick = function (event) {
        var isDisabled = hasClass(this.bsButtonEl, 'disabled');
        if (isDisabled) {
            return;
        }
        if (toLower(event.target.tagName) === 'a' && event.stopPropagation) {
            event.stopPropagation();
            event.preventDefault();
        }
        var closestCollapseToggleEl = closest(event.target, '[data-toggle="collapse"]');
        if (closestCollapseToggleEl && this.bsButtonEl.contains(closestCollapseToggleEl)) {
            // if (event.stopPropagation) {
            //   event.stopPropagation();
            //   event.preventDefault();
            // }
            BsButton.handleCollapseToggle(closestCollapseToggleEl);
        }
        var closestModalToggleEl = closest(event.target, '[data-toggle="modal"]');
        if (closestModalToggleEl && this.bsButtonEl.contains(closestModalToggleEl)) {
            // if (event.stopPropagation) {
            //   event.stopPropagation();
            //   event.preventDefault();
            // }
            BsButton.handleModalToggle(closestModalToggleEl);
        }
        this.handleToggle(event.target);
    };
    BsButton.handleCollapseToggle = function (relatedTarget) {
        var targetSelector = getTargetSelector(relatedTarget);
        if (targetSelector) {
            var parentArr = [];
            var targetElArr = Array.prototype.slice.call(document.querySelectorAll(targetSelector));
            for (var j = 0, len = targetElArr.length; j < len; j += 1) {
                if (targetElArr[j].collapse) {
                    targetElArr[j].collapse('toggle', relatedTarget);
                    if (targetElArr[j].dataset.parent) {
                        parentArr.push(targetElArr[j].dataset.parent);
                    }
                }
                else {
                    console.error('Unable to toggle collapse for all targets due to unavailable bs-collapse method "collapse');
                }
            }
            var parentDupes = getDuplicatesInArray(parentArr);
            for (var j = 0, len = parentDupes.length; j < len; j += 1) {
                console.warn("You are trying to toggle multiple collapses that have the same parent accordion (" + parentDupes[j] + ").\n                      Normally only one item in an accordion is toggled at one time.");
            }
        }
    };
    BsButton.handleModalToggle = function (relatedTarget) {
        var targetSelector = getTargetSelector(relatedTarget);
        if (targetSelector) {
            try {
                var targetEl = document.querySelector(targetSelector);
                if (targetEl.modal) {
                    targetEl.modal('toggle', relatedTarget);
                }
            }
            catch (err) {
                console.log('bs-button modal toggle target must be a valid css selector string');
                console.error(err.message);
            }
        }
    };
    BsButton.prototype.handleToggle = function (element) {
        var isDisabled = hasClass(this.bsButtonEl, 'disabled');
        if (isDisabled) {
            return;
        }
        if (!element || !this.bsButtonEl.contains(element)) {
            throw new Error('Invalid element unable to toggle');
        }
        var triggerChangeEvent = true;
        var addAriaPressed = true;
        var buttonsToggler = closest(element, '[data-toggle="buttons"]');
        if (buttonsToggler) {
            // button group
            // <div class="btn-group-toggle" data-toggle="buttons">
            //   <bs-button class="btn btn-secondary active">
            //     <input type="checkbox" checked autocomplete="off"> Checked
            //   </bs-button>
            // </div>
            var input = this.bsButtonEl.querySelector('input');
            if (input) {
                if (input.type === 'radio') {
                    if (input.checked && hasClass(input, 'active')) {
                        triggerChangeEvent = false;
                    }
                    else {
                        var activeElement = buttonsToggler.querySelector('.active');
                        if (activeElement) {
                            removeClass(activeElement, 'active');
                        }
                    }
                }
                if (triggerChangeEvent) {
                    input.checked = !hasClass(this.bsButtonEl, 'active');
                    customEvent(input, 'change');
                }
                if (this.addFocusClass) {
                    input.focus();
                }
                addAriaPressed = false;
            }
            if (addAriaPressed) {
                this.bsButtonEl.setAttribute('aria-pressed', hasClass(this.bsButtonEl, 'active') ? 'false' : 'true');
            }
            if (triggerChangeEvent) {
                toggleClass(this.bsButtonEl, 'active');
            }
            return;
        }
        if (this.bsButtonEl.dataset.toggle === 'button') {
            // standard button toggler
            //  <bs-button class="btn btn-primary" data-toggle="button" aria-pressed="false">
            //    Single toggle
            //  </bs-button>
            this.bsButtonEl.setAttribute('aria-pressed', hasClass(this.bsButtonEl, 'active') ? 'false' : 'true');
            toggleClass(this.bsButtonEl, 'active');
        }
    };
    BsButton.prototype.dropdown = function (dropdownOptions) {
        if (dropdownOptions === void 0) { dropdownOptions = {}; }
        // this is a proxy
        if (this.bsButtonEl.dataset.toggle !== 'dropdown') {
            throw new Error('dropdown method can only be run on a bs-button with [data-toggle="dropdown"]');
        }
        var bsDropdownEl = closest(this.bsButtonEl, 'bs-dropdown');
        if (!bsDropdownEl) {
            throw new Error('unable to find parent bs-dropdown component');
        }
        if (dropdownOptions === 'get-show') {
            return bsDropdownEl.show;
        }
        if (dropdownOptions === 'get-config') {
            return bsDropdownEl.config;
        }
        if (dropdownOptions === 'get-defaults') {
            return bsDropdownEl.defaults;
        }
        return bsDropdownEl.dropdown(dropdownOptions, this.bsButtonEl);
    };
    BsButton.prototype.button = function (buttonOptions) {
        if (buttonOptions === void 0) { buttonOptions = {}; }
        if (_size(buttonOptions) === 0) {
            return this.bsButtonEl;
        }
        if (buttonOptions === 'toggle') {
            this.handleToggle(this.bsButtonEl);
            return true;
        }
        if (typeof buttonOptions === 'string') {
            throw new Error("No method named \"" + buttonOptions + "\"");
        }
        return null;
    };
    BsButton.prototype.render = function () {
        return (h("slot", null));
    };
    Object.defineProperty(BsButton, "is", {
        get: function () { return "bs-button"; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BsButton, "properties", {
        get: function () {
            return {
                "addFocusClass": {
                    "state": true
                },
                "bsButtonEl": {
                    "elementRef": true
                },
                "button": {
                    "method": true
                },
                "dropdown": {
                    "method": true
                },
                "tabindex": {
                    "type": String,
                    "attr": "tabindex",
                    "reflectToAttr": true,
                    "mutable": true
                }
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BsButton, "listeners", {
        get: function () {
            return [{
                    "name": "focusin",
                    "method": "handleFocusIn"
                }, {
                    "name": "focusout",
                    "method": "handleFocusOut"
                }, {
                    "name": "keydown",
                    "method": "handleKeyDown"
                }, {
                    "name": "click",
                    "method": "handleButtonClick"
                }];
        },
        enumerable: true,
        configurable: true
    });
    return BsButton;
}());
export { BsButton };
