/*! Built with http://stenciljs.com */
import { h } from './bscomponents.core.js';
import { f as castSlice, n as hasUnicode, h as stringToArray, i as toString, y as overArg, c as baseGetTag, d as isObjectLike, p as _size, s as hasClass, r as removeClass, q as customEvent } from './chunk-d2b1926f.js';
import { a as _get } from './chunk-f0d1b1e1.js';
import { c as _has } from './chunk-7d6d9f73.js';
import { a as addClass } from './chunk-da49747d.js';
import { a as getTransitionDurationFromElement } from './chunk-df46c743.js';
import { a as reflow } from './chunk-89796593.js';
import { a as elementMatches } from './chunk-e18b632f.js';
import { a as getTargetSelector } from './chunk-65570c01.js';
import './chunk-ede00b3a.js';
/**
 * Creates a function like `_.lowerFirst`.
 *
 * @private
 * @param {string} methodName The name of the `String` case method to use.
 * @returns {Function} Returns the new case function.
 */
function createCaseFirst(methodName) {
    return function (string) {
        string = toString(string);
        var strSymbols = hasUnicode(string)
            ? stringToArray(string)
            : undefined;
        var chr = strSymbols
            ? strSymbols[0]
            : string.charAt(0);
        var trailing = strSymbols
            ? castSlice(strSymbols, 1).join('')
            : string.slice(1);
        return chr[methodName]() + trailing;
    };
}
var _createCaseFirst = createCaseFirst;
/**
 * Converts the first character of `string` to upper case.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category String
 * @param {string} [string=''] The string to convert.
 * @returns {string} Returns the converted string.
 * @example
 *
 * _.upperFirst('fred');
 * // => 'Fred'
 *
 * _.upperFirst('FRED');
 * // => 'FRED'
 */
var upperFirst = _createCaseFirst('toUpperCase');
var upperFirst_1 = upperFirst;
/** Built-in value references. */
var getPrototype = overArg(Object.getPrototypeOf, Object);
var _getPrototype = getPrototype;
/** `Object#toString` result references. */
var objectTag = '[object Object]';
/** Used for built-in method references. */
var funcProto = Function.prototype, objectProto = Object.prototype;
/** Used to resolve the decompiled source of functions. */
var funcToString = funcProto.toString;
/** Used to check objects for own properties. */
var hasOwnProperty = objectProto.hasOwnProperty;
/** Used to infer the `Object` constructor. */
var objectCtorString = funcToString.call(Object);
/**
 * Checks if `value` is a plain object, that is, an object created by the
 * `Object` constructor or one with a `[[Prototype]]` of `null`.
 *
 * @static
 * @memberOf _
 * @since 0.8.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 * }
 *
 * _.isPlainObject(new Foo);
 * // => false
 *
 * _.isPlainObject([1, 2, 3]);
 * // => false
 *
 * _.isPlainObject({ 'x': 0, 'y': 0 });
 * // => true
 *
 * _.isPlainObject(Object.create(null));
 * // => true
 */
function isPlainObject(value) {
    if (!isObjectLike(value) || baseGetTag(value) != objectTag) {
        return false;
    }
    var proto = _getPrototype(value);
    if (proto === null) {
        return true;
    }
    var Ctor = hasOwnProperty.call(proto, 'constructor') && proto.constructor;
    return typeof Ctor == 'function' && Ctor instanceof Ctor &&
        funcToString.call(Ctor) == objectCtorString;
}
var isPlainObject_1 = isPlainObject;
/**
 * Checks if `value` is likely a DOM element.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a DOM element, else `false`.
 * @example
 *
 * _.isElement(document.body);
 * // => true
 *
 * _.isElement('<body>');
 * // => false
 */
function isElement(value) {
    return isObjectLike(value) && value.nodeType === 1 && !isPlainObject_1(value);
}
var isElement_1 = isElement;
var BsCollapse = /** @class */ (function () {
    function BsCollapse() {
        this.showEventName = 'show.bs.collapse';
        this.shownEventName = 'shown.bs.collapse';
        this.hideEventName = 'hide.bs.collapse';
        this.hiddenEventName = 'hidden.bs.collapse';
    }
    BsCollapse.prototype.componentDidUnload = function () {
        this.relatedTarget = null;
    };
    BsCollapse.prototype.getConfig = function (overrideConfig, relatedTarget) {
        if (overrideConfig === void 0) { overrideConfig = {}; }
        if (relatedTarget === void 0) { relatedTarget = null; }
        var config = {};
        config.relatedTarget = relatedTarget;
        if (overrideConfig.toggle === true) {
            config.toggle = 'toggle';
        }
        else if (overrideConfig.toggle === false) {
            // keep the toggle state as is
            if (this.thisCollapseIsShown() === true) {
                config.toggle = 'show';
            }
            else {
                config.toggle = 'hide';
            }
        }
        else {
            config.toggle = _get(overrideConfig, 'toggle', 'toggle');
        }
        config.ignoreAccordion = _get(overrideConfig, 'ignoreAccordion', false);
        config.ignoreDataToggles = _get(overrideConfig, 'ignoreDataToggles', false);
        config.collapseElPlannedToBeOpened = [];
        config.collapseElPlannedToBeClosed = [];
        if (_has(overrideConfig, 'target')) {
            config.targetSelector = overrideConfig.target;
        }
        else if (relatedTarget && _has(relatedTarget.dataset, 'target')) {
            config.targetSelector = relatedTarget.dataset.target;
        }
        if (_has(overrideConfig, 'parent') && isElement_1(overrideConfig.parent)) {
            config.parent = overrideConfig.parent;
        }
        else if (_has(overrideConfig, 'parent') && typeof overrideConfig.parent === 'string' && _size(overrideConfig.parent) > 1) {
            config.parent = overrideConfig.parent;
        }
        else if (_has(this.collapseEl.dataset, 'parent')) {
            config.parent = this.collapseEl.dataset.parent;
        }
        return config;
    };
    BsCollapse.prototype.closeOtherOpenAccordions = function (config) {
        for (var j = 0, len = config.collapseElPlannedToBeClosed.length; j < len; j += 1) {
            if (config.collapseElPlannedToBeClosed[j].collapse && !this.collapseEl.isEqualNode(config.collapseElPlannedToBeClosed[j])) {
                config.collapseElPlannedToBeClosed[j].collapse({ toggle: 'hide', ignoreAccordion: true, ignoreDataToggles: true });
            }
            else {
                console.error('Unable to toggle collapse for all targets due to unavailable bs-collapse method "collapse');
            }
        }
    };
    BsCollapse.handleToggleDataToggles = function (config) {
        // handle all of the toggler [data-toggle="collapse"] dom state (mark them expanded or not)
        var allCollapsesOnPage = Array.prototype.slice.call(document.querySelectorAll('[data-toggle="collapse"]'));
        for (var j = 0, len = allCollapsesOnPage.length; j < len; j += 1) {
            var targetSelector = getTargetSelector(allCollapsesOnPage[j]);
            var thisCollapseWasOpened = false;
            if (_size(targetSelector) > 0) {
                // see if we need to open this collapse
                for (var x = 0, innerLen = config.collapseElPlannedToBeOpened.length; x < innerLen; x += 1) {
                    var shouldOpen = elementMatches(config.collapseElPlannedToBeOpened[x], targetSelector);
                    if (shouldOpen === true && thisCollapseWasOpened === false) {
                        removeClass(allCollapsesOnPage[j], 'collapsed');
                        allCollapsesOnPage[j].setAttribute('aria-expanded', 'true');
                        thisCollapseWasOpened = true;
                    }
                }
                // see if we need to close this collapse
                if (thisCollapseWasOpened === false) {
                    for (var x = 0, innerLen = config.collapseElPlannedToBeClosed.length; x < innerLen; x += 1) {
                        var shouldClose = elementMatches(config.collapseElPlannedToBeClosed[x], targetSelector);
                        if (shouldClose === true) {
                            var preExistingOpenTargets = document.querySelectorAll(targetSelector + ".show");
                            if (_size(preExistingOpenTargets) === 0) {
                                addClass(allCollapsesOnPage[j], 'collapsed');
                                allCollapsesOnPage[j].setAttribute('aria-expanded', 'false');
                            }
                        }
                    }
                }
            }
        }
    };
    BsCollapse.prototype.thisCollapseIsShown = function () {
        return hasClass(this.collapseEl, 'show') || hasClass(this.collapseEl, 'collapsing');
    };
    BsCollapse.prototype.handleToggle = function (config) {
        if (_has(config, 'parent') && config.ignoreAccordion !== true) {
            // if it has a parent then it is part of an accordion
            var accordionParentEl = void 0;
            if (isElement_1(config.parent)) {
                accordionParentEl = config.parent;
            }
            else {
                accordionParentEl = document.querySelector(config.parent);
                if (!accordionParentEl) {
                    console.warn("unable to find accordion parent by selector: \"" + config.parent + "\"");
                }
            }
            if (accordionParentEl) {
                var childCollapseArr = Array.prototype.slice.call(accordionParentEl.querySelectorAll('.collapse'));
                for (var j = 0, len = childCollapseArr.length; j < len; j += 1) {
                    if (hasClass(childCollapseArr[j], 'show')) {
                        var isAMemberOfThisAccordion = elementMatches(accordionParentEl, childCollapseArr[j].dataset.parent);
                        if (isAMemberOfThisAccordion) {
                            config.collapseElPlannedToBeClosed.push(childCollapseArr[j]);
                        }
                    }
                }
            }
        }
        if (config.toggle === 'show') {
            config.collapseElPlannedToBeOpened.push(this.collapseEl);
            this.showCollapse(this.collapseEl, config);
            return;
        }
        if (config.toggle === 'hide') {
            config.collapseElPlannedToBeClosed.push(this.collapseEl);
            this.hideCollapse(this.collapseEl, config);
            return;
        }
        // const thisCollapseIsShown = hasClass(this.collapseEl, 'show') || hasClass(this.collapseEl, 'collapsing');
        if (this.thisCollapseIsShown()) {
            config.collapseElPlannedToBeClosed.push(this.collapseEl);
            this.hideCollapse(this.collapseEl, config);
            return;
        }
        config.collapseElPlannedToBeOpened.push(this.collapseEl);
        this.showCollapse(this.collapseEl, config);
    };
    BsCollapse.prototype.showCollapse = function (targetEl, config) {
        var _this = this;
        if (hasClass(targetEl, 'show') || hasClass(targetEl, 'collapsing')) {
            return;
        }
        var showEvent = customEvent(targetEl, this.showEventName, {}, config.relatedTarget);
        if (showEvent.defaultPrevented) {
            return;
        }
        var dimension = BsCollapse.getDimension(targetEl);
        var scrollSize = "scroll" + upperFirst_1(dimension);
        addClass(targetEl, 'collapsing');
        removeClass(targetEl, 'collapse');
        if (config.ignoreAccordion !== true) {
            this.closeOtherOpenAccordions(config);
        }
        if (config.ignoreDataToggles !== true) {
            BsCollapse.handleToggleDataToggles(config);
        }
        var collapsingTransitionDuration = getTransitionDurationFromElement(targetEl);
        setTimeout(function () {
            removeClass(targetEl, 'collapsing');
            addClass(targetEl, 'collapse');
            addClass(targetEl, 'show');
            // eslint-disable-next-line no-param-reassign
            targetEl.style[dimension] = '';
            if (config.relatedTarget) {
                _this.relatedTarget = config.relatedTarget;
            }
            customEvent(targetEl, _this.shownEventName, {}, config.relatedTarget);
        }, collapsingTransitionDuration);
        // eslint-disable-next-line no-param-reassign
        targetEl.style[dimension] = targetEl[scrollSize] + "px";
    };
    BsCollapse.prototype.hideCollapse = function (targetEl, config) {
        var _this = this;
        if (!hasClass(targetEl, 'show')) {
            return;
        }
        var hideEvent = customEvent(targetEl, this.hideEventName, {}, this.relatedTarget);
        if (hideEvent.defaultPrevented) {
            return;
        }
        var dimension = BsCollapse.getDimension(targetEl);
        // eslint-disable-next-line no-param-reassign
        targetEl.style[dimension] = targetEl.getBoundingClientRect()[dimension] + "px";
        reflow(targetEl);
        addClass(targetEl, 'collapsing');
        removeClass(targetEl, 'collapse');
        removeClass(targetEl, 'show');
        // eslint-disable-next-line no-param-reassign
        targetEl.style[dimension] = '';
        if (config.ignoreDataToggles !== true) {
            BsCollapse.handleToggleDataToggles(config);
        }
        var collapsingTransitionDuration = getTransitionDurationFromElement(targetEl);
        setTimeout(function () {
            removeClass(targetEl, 'collapsing');
            addClass(targetEl, 'collapse');
            customEvent(targetEl, _this.hiddenEventName, {}, _this.relatedTarget);
            _this.relatedTarget = null;
        }, collapsingTransitionDuration);
    };
    BsCollapse.getDimension = function (el) {
        var hasWidth = hasClass(el, 'width');
        return hasWidth ? 'width' : 'height';
    };
    BsCollapse.prototype.collapse = function (collapseOptions, relatedTarget) {
        if (relatedTarget === void 0) { relatedTarget = null; }
        if (_size(collapseOptions) === 0) {
            return this.collapseEl;
        }
        if (collapseOptions === 'toggle') {
            this.handleToggle(this.getConfig({ toggle: 'toggle' }, relatedTarget));
            return true;
        }
        if (collapseOptions === 'show') {
            this.handleToggle(this.getConfig({ toggle: 'show' }, relatedTarget));
            return true;
        }
        if (collapseOptions === 'hide') {
            this.handleToggle(this.getConfig({ toggle: 'hide' }, relatedTarget));
            return true;
        }
        if (typeof collapseOptions === 'string') {
            throw new Error("No method named \"" + collapseOptions + "\"");
        }
        if (typeof collapseOptions === 'object') {
            this.handleToggle(this.getConfig(collapseOptions, relatedTarget));
            return true;
        }
        return null;
    };
    BsCollapse.prototype.render = function () {
        return (h("slot", null));
    };
    Object.defineProperty(BsCollapse, "is", {
        get: function () { return "bs-collapse"; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BsCollapse, "properties", {
        get: function () {
            return {
                "collapse": {
                    "method": true
                },
                "collapseEl": {
                    "elementRef": true
                },
                "hiddenEventName": {
                    "type": String,
                    "attr": "hidden-event-name"
                },
                "hideEventName": {
                    "type": String,
                    "attr": "hide-event-name"
                },
                "relatedTarget": {
                    "state": true
                },
                "showEventName": {
                    "type": String,
                    "attr": "show-event-name"
                },
                "shownEventName": {
                    "type": String,
                    "attr": "shown-event-name"
                }
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BsCollapse, "style", {
        get: function () { return "bs-collapse {\n  display: block;\n}"; },
        enumerable: true,
        configurable: true
    });
    return BsCollapse;
}());
export { BsCollapse };
